The default simulation parameters are terrible, can I change them?
==================================================================

Of course! This is done using the ``dptools get`` and ``dptools set`` commands.
:ref:`Click here for more details<mod_params>`.
